@@ -12,7 +12,10 @@
 #' @keywords internal
 #' @noRd
 get_condathis_path <- function() {
-  if (isTRUE(Sys.getenv(x = "XDG_DATA_HOME") == "") && isTRUE(stringr::str_detect(get_sys_arch(), pattern = "^Darwin"))) {
+  if (
+    isTRUE(Sys.getenv(x = "XDG_DATA_HOME") == "") &&
+      isTRUE(stringr::str_detect(get_sys_arch(), pattern = "^Darwin"))
+  ) {
     withr::local_envvar(
       .new = list(
         `XDG_DATA_HOME` = fs::path_home(".local", "share")
