@@ -5,9 +5,9 @@
 #' @keywords internal
 #' @noRd
 micromamba_user_installed <- function() {
-  umamba_bin_path <- Sys.which("micromamba")
-  if (isTRUE(umamba_bin_path == "")) {
-    umamba_bin_path <- Sys.which("micromamba.exe")
+  umamba_bin_path <- get_best_micromamba_path()
+  if (rlang::is_null(umamba_bin_path)) {
+    umamba_bin_path <- ""
   }
   if (isTRUE(umamba_bin_path == "")) {
     return(invisible(umamba_bin_path))
