@@ -5,18 +5,18 @@ test_that("Native run conda command", {
   px_res <- native_cmd("--help", verbose = FALSE)
   expect_equal(
     object = px_res$status,
-    expected = 0
+    expected = 0L
   )
 
   px_res <- native_cmd("env", "list", verbose = FALSE)
   expect_equal(
     object = px_res$status,
-    expected = 0
+    expected = 0L
   )
 
   px_res <- native_cmd("--version", verbose = FALSE)
   expect_equal(
     object = px_res$status,
-    expected = 0
+    expected = 0L
   )
 })
